@@ -6,6 +6,7 @@ import {
   behaviors,
   ConstantVariable,
   SceneDataTransformer,
+  SceneGridItem,
   SceneGridLayout,
   SceneGridRow,
   SceneQueryRunner,
@@ -24,7 +25,7 @@ import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
 import { PanelModel } from 'app/features/dashboard/state/PanelModel';
 import { createPanelSaveModel } from 'app/features/dashboard/state/__fixtures__/dashboardFixtures';
 import { SHARED_DASHBOARD_QUERY, DASHBOARD_DATASOURCE_PLUGIN_ID } from 'app/plugins/datasource/dashboard/constants';
-import { DashboardDataDTO } from 'app/types';
+import { DashboardDataDTO } from 'app/types/dashboard';
 
 import { DashboardDataLayerSet } from '../scene/DashboardDataLayerSet';
 import { LibraryPanelBehavior } from '../scene/LibraryPanelBehavior';
@@ -32,6 +33,7 @@ import { PanelTimeRange } from '../scene/PanelTimeRange';
 import { DashboardGridItem } from '../scene/layout-default/DashboardGridItem';
 import { DefaultGridLayoutManager } from '../scene/layout-default/DefaultGridLayoutManager';
 import { RowRepeaterBehavior } from '../scene/layout-default/RowRepeaterBehavior';
+import { RowsLayoutManager } from '../scene/layout-rows/RowsLayoutManager';
 import { NEW_LINK } from '../settings/links/utils';
 import { getQueryRunnerFor } from '../utils/utils';
 
@@ -40,6 +42,7 @@ import { GRAFANA_DATASOURCE_REF } from './const';
 import { SnapshotVariable } from './custom-variables/SnapshotVariable';
 import dashboard_to_load1 from './testfiles/dashboard_to_load1.json';
 import repeatingRowsAndPanelsDashboardJson from './testfiles/repeating_rows_and_panels.json';
+import rowsAfterFreePanels from './testfiles/rows_after_free_panels.json';
 import {
   createDashboardSceneFromDashboardModel,
   buildGridItemForPanel,
@@ -807,6 +810,100 @@ describe('transformSaveModelToScene', () => {
       expect((libPanelBehavior as LibraryPanelBehavior).state.name).toEqual(panel.libraryPanel.name);
       expect(gridItem.state.body.state.title).toEqual(panel.title);
     });
+
+    describe('header actions', () => {
+      beforeEach(() => {
+        jest.clearAllMocks();
+      });
+
+      it('should include headerActions when timeComparison feature toggle is enabled', () => {
+        config.featureToggles.timeComparison = true;
+
+        const panel = {
+          title: 'Test Panel',
+          type: 'timeseries',
+          gridPos: { x: 0, y: 0, w: 12, h: 8 },
+        };
+
+        const { vizPanel } = buildGridItemForTest(panel);
+
+        expect(vizPanel.state.headerActions).toBeDefined();
+        expect(vizPanel.state.headerActions).toHaveLength(1);
+      });
+
+      it('should not include headerActions when timeComparison feature toggle is disabled', () => {
+        config.featureToggles.timeComparison = false;
+
+        const panel = {
+          title: 'Test Panel',
+          type: 'timeseries',
+          gridPos: { x: 0, y: 0, w: 12, h: 8 },
+        };
+
+        const { vizPanel } = buildGridItemForTest(panel);
+
+        expect(vizPanel.state.headerActions).toBeUndefined();
+      });
+    });
+  });
+
+  describe('Convert to new rows', () => {
+    beforeEach(() => {
+      // set feature flag to true
+      config.featureToggles.dashboardNewLayouts = true;
+    });
+    afterEach(() => {
+      config.featureToggles.dashboardNewLayouts = false;
+    });
+
+    it('Should convert legacy rows to new rows', () => {
+      const scene = transformSaveModelToScene({
+        dashboard: repeatingRowsAndPanelsDashboardJson as DashboardDataDTO,
+        meta: {},
+      });
+
+      const layout = scene.state.body as RowsLayoutManager;
+      const row1 = layout.state.rows[0];
+
+      expect(row1.state.title).toBe('Row at the top - not repeated - saved expanded');
+      const row1Layout = row1.state.layout as DefaultGridLayoutManager;
+      expect(row1Layout.state.grid.state.children).toHaveLength(1);
+      const row1gridItem = row1Layout.state.grid.state.children[0] as SceneGridItem;
+      expect(row1gridItem.state.body).toBeInstanceOf(VizPanel);
+      const row1Panel = row1gridItem.state.body as VizPanel;
+      expect(row1Panel.state.pluginId).toBe('text');
+      const row1PanelOptions = row1Panel.state.options as { content: string };
+      expect(row1PanelOptions.content).toBe(
+        '<div class=\"center-vh\">\n  Repeated row below. The row has \n  a panel that is also repeated horizontally based\n  on values in the $pod variable. \n</div>'
+      );
+
+      const row2 = layout.state.rows[1];
+
+      expect(row2.state.repeatByVariable).toBe('server');
+
+      const lastRow = layout.state.rows[layout.state.rows.length - 1];
+      expect(lastRow.state.title).toBe('Row at the bottom - not repeated - saved collapsed ');
+      const lastRowLayout = lastRow.state.layout as DefaultGridLayoutManager;
+      expect(lastRowLayout.state.grid.state.children).toHaveLength(1);
+      const lastRowgridItem = lastRowLayout.state.grid.state.children[0] as SceneGridItem;
+      expect(lastRowgridItem.state.body).toBeInstanceOf(VizPanel);
+      const lastRowPanel = lastRowgridItem.state.body as VizPanel;
+      expect(lastRowPanel.state.pluginId).toBe('text');
+    });
+
+    it('Should convert legacy rows to new rows with free panels before first row', () => {
+      const scene = transformSaveModelToScene({
+        dashboard: rowsAfterFreePanels as DashboardDataDTO,
+        meta: {},
+      });
+
+      const layout = scene.state.body as RowsLayoutManager;
+      const row1 = layout.state.rows[0];
+      expect(row1.state.title).toBe('');
+      expect(row1.state.hideHeader).toBe(true);
+      const row1Layout = row1.state.layout as DefaultGridLayoutManager;
+      expect(row1Layout.state.grid.state.children).toHaveLength(1);
+    });
   });
 
   describe('Repeating rows', () => {
